# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Perl-Tidy
Version:	20250311
Release:	1.%{__distinit}%{__distvers}
Summary:	Tool for indenting and re-formatting Perl scripts
License:	GPL-2.0-or-later
URL:		http://perltidy.sourceforge.net/
Source0:	https://cpan.metacpan.org/modules/by-module/Perl/Perl-Tidy-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	sed
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(constant)
BuildRequires:	perl(Cwd)
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(Digest::MD5)
BuildRequires:	perl(Encode)
BuildRequires:	perl(English)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(File::Basename)
BuildRequires:	perl(File::Copy)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(Getopt::Long)
BuildRequires:	perl(HTML::Entities)
BuildRequires:	perl(IO::File)
BuildRequires:	perl(List::Util)
BuildRequires:	perl(Pod::Html)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(vars)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(FindBin)
BuildRequires:	perl(Test)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(utf8)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(File::Spec)
Requires:	perl(File::Temp)
Requires:	perl(HTML::Entities)
Requires:	perl(Pod::Html)

# This package is called perltidy in Fedora
Obsoletes:	perltidy < %{version}-%{release}
Provides:	perltidy = %{version}-%{release}

# EL-7's dependency generator picks up things from documentation that it shouldn't do,
# though strangely the one in F-19 does not, despite both being rpm 4.11.3
%if 0%{?el7}
%global __requires_exclude ^perl[(]([*]?[{}]|[)])?[)]
%endif

%description
Perltidy is a Perl script that indents and re-formats Perl scripts to
make them easier to read. If you write Perl scripts, or spend much
time reading them, you will probably find it useful. The formatting
can be controlled with command line parameters. The default parameter
settings approximately follow the suggestions in the Perl Style Guide.
Perltidy can also output HTML of both POD and source code. Besides
re-formatting scripts, Perltidy can be a great help in tracking down
errors with missing or extra braces, parentheses, and square brackets
because it is very good at localizing errors.

%prep
%setup -q -n Perl-Tidy-%{version}

# Don't need Windows batch file
rm examples/pt.bat

# Quieten complaints about missing files
sed -i -e '/^examples\/pt\.bat/d' MANIFEST

# Remove unwanted exec permissions
find examples/ lib/ -type f -perm /a+x -exec chmod -c -x {} \;

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license COPYING
%doc BUGS.md CHANGES.md README.md docs/ examples/
%{_bindir}/perltidy
%{perl_vendorlib}/Perl/
%{_mandir}/man1/perltidy.1*
%{_mandir}/man3/Perl::Tidy.3*

%changelog
* Wed Mar 12 2025 Paul Howarth <paul@city-fan.org> - 20250311-1
- Update to 20250311 (see CHANGES.md for details) (rhbz#2351446)

* Thu Feb 13 2025 Paul Howarth <paul@city-fan.org> - 20250214-1
- Update to 20250214 (see CHANGES.md for details) (rhbz#2345575)

* Mon Jan 20 2025 Paul Howarth <paul@city-fan.org> - 20250105-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild

* Sun Jan  5 2025 Paul Howarth <paul@city-fan.org> - 20250105-1
- Update to 20250105 (see CHANGES.md for details)

* Tue Sep  3 2024 Paul Howarth <paul@city-fan.org> - 20240903-1
- Update to 20240903 (see CHANGES.md for details)

* Sun Jul 21 2024 Paul Howarth <paul@city-fan.org> - 20240511-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Sun May 12 2024 Paul Howarth <paul@city-fan.org> - 20240511-1
- Update to 20240511 (see CHANGES.md for details)

* Thu Feb  1 2024 Paul Howarth <paul@city-fan.org> - 20240202-1
- Update to 20240202 (see CHANGES.md for details)

* Wed Sep 13 2023 Paul Howarth <paul@city-fan.org> - 20230912-1
- Update to 20230912
  - Remove a syntax error check that could cause an incorrect error message
    when List::Gather::gather was used (GH#124)

* Sat Sep  9 2023 Paul Howarth <paul@city-fan.org> - 20230909-1
- Update to 20230909 (see CHANGES.md for details)

* Sat Jul  1 2023 Paul Howarth <paul@city-fan.org> - 20230701-1
- Update to 20230701 (see CHANGES.md for details)

* Thu Mar  9 2023 Paul Howarth <paul@city-fan.org> - 20230309-1
- Update to 20230309 (see CHANGES.md for details)

* Fri Nov 11 2022 Paul Howarth <paul@city-fan.org> - 20221112-1
- Update to 20221112
  - Fix undef warning in Perl before 5.12 (CPAN RT#145095)

* Thu Nov 10 2022 Paul Howarth <paul@city-fan.org> - 20221111-1
- Update to 20221111 (see CHANGES.md for details)
- Use SPDX-format license tag

* Mon Jun 13 2022 Paul Howarth <paul@city-fan.org> - 20220613-1
- Update to 20220613 (see CHANGES.md for details)

* Tue Feb 15 2022 Paul Howarth <paul@city-fan.org> - 20220217-1
- Update to 20220217 (see CHANGES.md for details)

* Tue Feb 15 2022 Paul Howarth <paul@city-fan.org> - 20220215-1
- Update to 20220215 (see CHANGES.md for details)
- Add workaround for bogus dependencies generated on EL-7

* Fri Oct 29 2021 Paul Howarth <paul@city-fan.org> - 20211029-1
- Update to 20211029 (see CHANGES.md for details)

* Sat Jul 17 2021 Paul Howarth <paul@city-fan.org> - 20210717-1
- Update to 20210717 (see CHANGES.md for details)
- Fix dist tags for Alma and Rocky Linux

* Thu Jun 24 2021 Paul Howarth <paul@city-fan.org> - 20210625-1
- Update to 20210625 (see CHANGES.md for details)

* Thu Apr  1 2021 Paul Howarth <paul@city-fan.org> - 20210402-1
- Update to 20210402 (see CHANGES.md for details)

* Mon Jan 11 2021 Paul Howarth <paul@city-fan.org> - 20210111-1
- Update to 20210111 (see CHANGES.md for details)
- Use %%license unconditionally

* Mon Dec  7 2020 Paul Howarth <paul@city-fan.org> - 20201207-1
- Update to 20201207 (see CHANGES.md for details)

* Thu Dec  3 2020 Paul Howarth <paul@city-fan.org> - 20201202-1
- Update to 20201202 (see CHANGES.md for details)

* Tue Sep 29 2020 Paul Howarth <paul@city-fan.org> - 20201001-1
- Update to 20201001 (see CHANGES.md for details)

* Mon Sep  7 2020 Paul Howarth <paul@city-fan.org> - 20200907-1
- Update to 20200907 (see CHANGES.md for details)

* Sat Aug 22 2020 Paul Howarth <paul@city-fan.org> - 20200822-1
- Update to 20200822 (see CHANGES.md for details)

* Wed Jul 29 2020 Paul Howarth <paul@city-fan.org> - 20200619-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Sat Jun 20 2020 Paul Howarth <paul@city-fan.org> - 20200619-1
- Update to 20200619 (see CHANGES.md for details)

* Fri Jan 10 2020 Paul Howarth <paul@city-fan.org> - 20200110-1
- Update to 20200110 (see CHANGES.md for details)

* Tue Dec  3 2019 Paul Howarth <paul@city-fan.org> - 20191203-1
- Update to 20191203 (see CHANGES.md for details)

* Sun Sep 15 2019 Paul Howarth <paul@city-fan.org> - 20190915-1
- Update to 20190915 (see CHANGES.md for details)

* Fri Jul 26 2019 Paul Howarth <paul@city-fan.org> - 20190601-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Mon Jun  3 2019 Paul Howarth <paul@city-fan.org> - 20190601-1
- Update to 20190601 (see CHANGES.md for details)

* Mon Nov 19 2018 Paul Howarth <paul@city-fan.org> - 20181120-1
- Update to 20181120 (see CHANGES.md for details)
- Drop UTF-8 patch, no longer needed
- Text documentation converted to markdown upstream

* Wed Feb 21 2018 Paul Howarth <paul@city-fan.org> - 20180220-1
- Update to 20180220
  - Fix index error causing perltidy to fail, resulting in empty files
    (CPAN RT#124469, CPAN RT#124494)

* Mon Feb 19 2018 Paul Howarth <paul@city-fan.org> - 20180219-1
- Update to 20180219 (see CHANGES for details)

* Mon Jan  1 2018 Paul Howarth <paul@city-fan.org> - 20180101-1
- Update to 20180101 (see CHANGES for details)

* Fri Dec 15 2017 Paul Howarth <paul@city-fan.org> - 20171214-1
- Update to 20171214 (see CHANGES for details)

* Mon May 22 2017 Paul Howarth <paul@city-fan.org> - 20170521-1
- Update to 20170521
  - Includes fix for CVE-2016-10374: Uses current working directory without
    symlink-attack protection
  - See CHANGES for details of other bug fixes and enhancements
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Sat Feb 11 2017 Paul Howarth <paul@city-fan.org> - 20160302-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Sep 21 2016 Paul Howarth <paul@city-fan.org> - 20160302-2
- BR: perl-generators where available
- Simplify find command using -delete

* Tue Mar  1 2016 Paul Howarth <paul@city-fan.org> - 20160302-1
- Update to 20160302
  - Corrected a minor problem in which an unwanted newline was placed before
    the closing brace of an anonymous sub with a signature, if it was in a
    list (CPAN RT#112534)
  - Corrected a minor problem in which occasional extra indentation was given
    to the closing brace of an anonymous sub in a list when the -lp parameter
    was set

* Mon Feb 29 2016 Paul Howarth <paul@city-fan.org> - 20160301-1
- Update to 20160301 (see CHANGES for details)

* Sat Aug 15 2015 Paul Howarth <paul@city-fan.org> - 20150815-1
- Update to 20150815 (see CHANGES for details)
- Use %%license where possible

* Mon Jul 14 2014 Paul Howarth <paul@city-fan.org> - 20140711-1
- Update to 20140711 (see CHANGES for details)

* Fri Mar 28 2014 Paul Howarth <paul@city-fan.org> - 20140328-1
- Update to 20140328
  - Fixed CPAN RT#94190 and debian Bug #742004: perltidy.LOG file left behind;
    the problem was caused by the memoization speedup patch in version
    20121207: an unwanted flag was being set, which caused a LOG to be written
    if perltidy was called multiple times
  - New default behavior for LOG files: if the source is from an array or
    string (through a call to the perltidy module) then a LOG output is only
    possible if a logfile stream is specified; this is to prevent unexpected
    perltidy.LOG files
  - Fixed debian Bug #740670, insecure temporary file usage; File::Temp is now
    used to get a temporary file (CVE-2014-2277)
  - Any -b (--backup-and-modify-in-place) flag is silently ignored when a
    source stream, destination stream, or standard output is used; this is
    because the -b flag may have been in a .perltidyrc file and warnings break
    Test::NoWarnings
- Drop upstreamed patch for CVE-2014-2277
- Classify buildreqs by usage

* Tue Mar 25 2014 Paul Howarth <paul@city-fan.org> - 20130922-3
- License is GPLv2+, not GPL+
- Drop %%defattr, redundant since rpm 4.4
- BR: perl(Test)
- Use author-independent source URL
- Use upstream sourceforge site URL

* Thu Mar 13 2014 Paul Howarth <paul@city-fan.org> - 20130922-2
- Fix insecure temporary file usage (CVE-2014-2277)

* Mon Sep 23 2013 Paul Howarth <paul@city-fan.org> - 20130922-1
- Update to 20130922
  - Fixed CPAN RT#88020, --converge was not working with wide characters
  - Fixed CPAN RT#78156, package NAMESPACE VERSION syntax not accepted
  - First attempt to fix CPAN RT#88588, INDEX END tag change in pod2html breaks
    perltidy -html; I put in a patch which should work but I don't yet have a
    way of testing it

* Tue Aug  6 2013 Paul Howarth <paul@city-fan.org> - 20130806-1
- Update to 20130806
  - Fixed CPAN RT#87502, incorrect of parsing of smartmatch before hash brace
  - Added feature request CPAN RT#87330, trim whitespace after POD;
    the flag -trp (--trim-pod) will trim trailing whitespace from lines of POD
  - Fixed CPAN RT#87107, spelling

* Wed Jul 17 2013 Paul Howarth <paul@city-fan.org> - 20130717-1
- Update to 20130717
  - Fixed CPAN RT#86929, CPAN RT#86930, missing lhs of assignment
  - Fixed CPAN RT#84922, moved pod from Tidy.pm into Tidy.pod

* Mon Dec 10 2012 Paul Howarth <paul@city-fan.org> - 20121207-1
- Update to 20121207 (see CHANGES for details)

* Sat Jul 14 2012 Paul Howarth <paul@city-fan.org> - 20120714-1
- Update to 20120714 (see CHANGES for details)

* Mon Jul  2 2012 Paul Howarth <paul@city-fan.org> - 20120701-1
- Update to 20120701 (see CHANGES for details)

* Wed Jun 20 2012 Paul Howarth <paul@city-fan.org> - 20120619-1
- Update to 20120619 (see CHANGES for details)

* Mon Jun 11 2012 Paul Howarth <paul@city-fan.org> - 20101217-5
- BR: perl(Carp), perl(constant), perl(Cwd), perl(Exporter),
  perl(Getopt::Long) and perl(IO::File)
- Use a patch rather than scripted iconv to fix character encoding
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Use %%{_fixperms} macro rather than our own chmod incantation

* Wed Jun 29 2011 Paul Howarth <paul@city-fan.org> - 20101217-2
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri Dec 17 2010 Paul Howarth <paul@city-fan.org> - 20101217-1
- Update to 20101217 (see CHANGES for details)

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> - 20090616-5
- Rebuild for perl 5.12.1 in Rawhide

* Wed Jun  2 2010 Paul Howarth <paul@city-fan.org> - 20090616-4
- Fix dist tag for RHEL-6 Beta

* Wed Nov 25 2009 Paul Howarth <paul@city-fan.org> - 20090616-3
- Import from Fedora's perltidy package

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 20090616-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Jun 18 2009 Ville Skyttä <ville.skytta at iki.fi> - 20090616-1
- Update to 20090616

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 20071205-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 20071205-3
- Rebuild for perl 5.10 (again)

* Sun Jan 13 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 20071205-2
- Rebuild for new perl

* Thu Dec  6 2007 Ville Skyttä <ville.skytta at iki.fi> - 20071205-1
- 20071205
- Convert docs to UTF-8

* Wed Aug  1 2007 Ville Skyttä <ville.skytta at iki.fi> - 20070801-1
- 20070801

* Wed May  9 2007 Ville Skyttä <ville.skytta at iki.fi> - 20070508-1
- 20070508

* Sat May  5 2007 Ville Skyttä <ville.skytta at iki.fi> - 20070504-1
- 20070504

* Tue Apr 24 2007 Ville Skyttä <ville.skytta at iki.fi> - 20070424-1
- 20070424

* Tue Apr 17 2007 Ville Skyttä <ville.skytta at iki.fi> - 20060719-3
- BuildRequire perl(ExtUtils::MakeMaker)

* Fri Sep 15 2006 Ville Skyttä <ville.skytta at iki.fi> - 20060719-2
- Rebuild

* Thu Jul 20 2006 Ville Skyttä <ville.skytta at iki.fi> - 20060719-1
- 20060719
- Fix order of options to find(1) in %%install

* Thu Jun 15 2006 Ville Skyttä <ville.skytta at iki.fi> - 20060614-1
- 20060614, specfile cleanups, include examples in docs

* Wed Apr  6 2005 Michael Schwendt <mschwendt[AT]users.sf.net>
- Rebuilt

* Thu Dec 16 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:20031021-1
- Sync with fedora-rpmdevtools' Perl spec template to fix x86_64 build
- Move version to the version field

* Wed Oct 22 2003 Ville Skyttä <ville.skytta at iki.fi> 0:0.0-0.fdr.3.20031021
- Update to 20031021

* Sat Oct 11 2003 Ville Skyttä <ville.skytta at iki.fi> 0:0.0-0.fdr.3.20030726
- Install into vendor dirs
- Spec cleanups

* Tue Jul 29 2003 Ville Skyttä <ville.skytta at iki.fi> 0:0.0-0.fdr.2.20030726
- Update to 20030726
- Use fedora-rpm-helper

* Mon Jun 23 2003 Ville Skyttä <ville.skytta at iki.fi> 0:0.0-0.fdr.2.20021130
- Address issues in #194:
- Patch to get rid of a warning on startup
- Do defattr before doc

* Fri May 30 2003 Ville Skyttä <ville.skytta at iki.fi> 0:0.0-0.fdr.1.20021130
- Fix release naming scheme (this is snapshot-only)

* Wed May  7 2003 Ville Skyttä <ville.skytta at iki.fi> 0:0.0-0.fdr.0.2.20021130
- Own dirs
- Save .spec in UTF-8

* Mon Apr 21 2003 Ville Skyttä <ville.skytta at iki.fi> 0:0.0-0.fdr.0.1.20021130
- First Fedora release, based on Simon Perreault's work

* Mon Mar 10 2003 Simon Perreault <nomis80@nomis80.org> 20021130-2
- Changed architecture from i386 to noarch
- Added my name as packager
- Bumped up release number, which was forgotten by Anthony Rumble

* Sun Mar 09 2003 Anthony Rumble <anthony@linuxhelp.com.au>
- Tidied up RPM Source

* Sun Dec  1 2002 Simon Perreault <nomis80@linuxquebec.com>
- Update to 20021130

* Sat Nov  9 2002 Simon Perreault <nomis80@linuxquebec.com>
- Update to 20021106

* Mon Sep 23 2002 Simon Perreault <nomis80@linuxquebec.com>
- Update to 20020922

* Wed Aug 28 2002 Simon Perreault <nomis80@linuxquebec.com>
- Update to 20020826

* Tue May 7 2002 Simon Perreault <nomis80@linuxquebec.com>
- Require 5.6.1 because Tidy.pm is placed in a directory dependant on perl
  version

* Sat Apr 27 2002 Simon Perreault <nomis80@linuxquebec.com>
- Update to 20020425

* Wed Apr 17 2002 Simon Perreault <nomis80@linuxquebec.com>
- Generalized spec file
- Added some documentation

* Wed Apr 17 2002 Simon Perreault <nomis80@linuxquebec.com>
- Upgraded to version 20020416

* Mon Feb 25 2002 Simon Perreault <nomis80@linuxquebec.com>
- Spec file was created on release of 20020225
